# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_broadcast.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import service as _service
from google.protobuf import service_reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='steammessages_broadcast.proto',
  package='',
  syntax='proto2',
  serialized_pb=b'\n\x1dsteammessages_broadcast.proto\x1a steammessages_unified_base.proto\"\x9d\x01\n(CBroadcast_BeginBroadcastSession_Request\x12\x12\n\npermission\x18\x01 \x01(\x05\x12\x0e\n\x06gameid\x18\x02 \x01(\x04\x12\x1a\n\x12\x63lient_instance_id\x18\x03 \x01(\x04\x12\r\n\x05title\x18\x04 \x01(\t\x12\x0e\n\x06\x63\x65llid\x18\x05 \x01(\r\x12\x12\n\nrtmp_token\x18\x06 \x01(\x04\"A\n)CBroadcast_BeginBroadcastSession_Response\x12\x14\n\x0c\x62roadcast_id\x18\x01 \x01(\x06\">\n&CBroadcast_EndBroadcastSession_Request\x12\x14\n\x0c\x62roadcast_id\x18\x01 \x01(\x06\")\n\'CBroadcast_EndBroadcastSession_Response\"w\n\'CBroadcast_StartBroadcastUpload_Request\x12\x14\n\x0c\x62roadcast_id\x18\x01 \x01(\x06\x12\x0e\n\x06\x63\x65llid\x18\x02 \x01(\r\x12\x0f\n\x07\x61s_rtmp\x18\x03 \x01(\x08\x12\x15\n\rdelay_seconds\x18\x04 \x01(\r\"q\n(CBroadcast_StartBroadcastUpload_Response\x12\x14\n\x0cupload_token\x18\x01 \x01(\t\x12\x16\n\x0eupload_address\x18\x02 \x01(\t\x12\x17\n\x0fupload_relay_id\x18\x03 \x01(\x06\"f\n1CBroadcast_NotifyBroadcastUploadStop_Notification\x12\x1a\n\x12\x62roadcast_relay_id\x18\x01 \x01(\x06\x12\x15\n\rupload_result\x18\x02 \x01(\r\"\x91\x01\n!CBroadcast_WatchBroadcast_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x1d\n\x15\x65xisting_broadcast_id\x18\x02 \x01(\x06\x12\x14\n\x0cviewer_token\x18\x03 \x01(\x06\x12\x11\n\tclient_ip\x18\x04 \x01(\r\x12\x13\n\x0b\x63lient_cell\x18\x05 \x01(\r\"\xd7\x05\n\"CBroadcast_WatchBroadcast_Response\x12[\n\x08response\x18\x01 \x01(\x0e\x32\x32.CBroadcast_WatchBroadcast_Response.EWatchResponse:\x15k_EWatchResponseReady\x12\x0f\n\x07mpd_url\x18\x02 \x01(\t\x12\x14\n\x0c\x62roadcast_id\x18\x03 \x01(\x06\x12\x0e\n\x06gameid\x18\x04 \x01(\x04\x12\r\n\x05title\x18\x05 \x01(\t\x12\x13\n\x0bnum_viewers\x18\x06 \x01(\r\x12\x12\n\npermission\x18\x07 \x01(\x05\x12\x0f\n\x07is_rtmp\x18\x08 \x01(\x08\x12\x15\n\rseconds_delay\x18\t \x01(\x05\x12\x14\n\x0cviewer_token\x18\n \x01(\x06\"\xa6\x03\n\x0e\x45WatchResponse\x12\x19\n\x15k_EWatchResponseReady\x10\x01\x12 \n\x1ck_EWatchResponseNotAvailable\x10\x02\x12&\n\"k_EWatchResponseWaitingForApproval\x10\x03\x12#\n\x1fk_EWatchResponseWaitingForStart\x10\x04\x12\"\n\x1ek_EWatchResponseInvalidSession\x10\x05\x12%\n!k_EWatchResponseTooManyBroadcasts\x10\x06\x12\'\n#k_EWatchResponseWaitingForReconnect\x10\x07\x12&\n\"k_EWatchResponseSystemNotSupported\x10\x08\x12\"\n\x1ek_EWatchResponseUserRestricted\x10\t\x12#\n\x1fk_EWatchResponseClientOutOfDate\x10\n\x12%\n!k_EWatchResponsePoorUploadQuality\x10\x0b\"N\n%CBroadcast_GetBroadcastStatus_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x14\n\x0c\x62roadcast_id\x18\x02 \x01(\x06\"\xae\x01\n&CBroadcast_GetBroadcastStatus_Response\x12\x0e\n\x06gameid\x18\x01 \x01(\x04\x12\r\n\x05title\x18\x02 \x01(\t\x12\x13\n\x0bnum_viewers\x18\x03 \x01(\r\x12\x12\n\npermission\x18\x04 \x01(\x05\x12\x0f\n\x07is_rtmp\x18\x05 \x01(\x08\x12\x15\n\rseconds_delay\x18\x06 \x01(\x05\x12\x14\n\x0cis_publisher\x18\x07 \x01(\x08\"R\n$CBroadcast_InviteToBroadcast_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x19\n\x11\x61pproval_response\x18\x02 \x01(\x08\"8\n%CBroadcast_InviteToBroadcast_Response\x12\x0f\n\x07success\x18\x01 \x01(\x08\"|\n-CBroadcast_SendBroadcastStateToServer_Request\x12\x12\n\npermission\x18\x01 \x01(\x05\x12\x0e\n\x06gameid\x18\x02 \x01(\x04\x12\r\n\x05title\x18\x03 \x01(\t\x12\x18\n\x10game_data_config\x18\x04 \x01(\t\"0\n.CBroadcast_SendBroadcastStateToServer_Response\"O\n7CBroadcast_NotifyBroadcastSessionHeartbeat_Notification\x12\x14\n\x0c\x62roadcast_id\x18\x01 \x01(\x06\"x\n\'CBroadcast_GetBroadcastChatInfo_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x14\n\x0c\x62roadcast_id\x18\x02 \x01(\x06\x12\x11\n\tclient_ip\x18\x03 \x01(\r\x12\x13\n\x0b\x63lient_cell\x18\x04 \x01(\r\"h\n(CBroadcast_GetBroadcastChatInfo_Response\x12\x0f\n\x07\x63hat_id\x18\x01 \x01(\x06\x12\x10\n\x08view_url\x18\x02 \x01(\t\x12\x19\n\x11view_url_template\x18\x03 \x01(\t\"[\n\"CBroadcast_PostChatMessage_Request\x12\x0f\n\x07\x63hat_id\x18\x01 \x01(\x06\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x13\n\x0binstance_id\x18\x03 \x01(\r\"\\\n#CBroadcast_PostChatMessage_Response\x12\x14\n\x0cpersona_name\x18\x01 \x01(\t\x12\x0f\n\x07in_game\x18\x02 \x01(\x08\x12\x0e\n\x06result\x18\x03 \x01(\x05\"`\n(CBroadcast_MuteBroadcastChatUser_Request\x12\x0f\n\x07\x63hat_id\x18\x01 \x01(\x06\x12\x14\n\x0cuser_steamid\x18\x02 \x01(\x06\x12\r\n\x05muted\x18\x03 \x01(\x08\"+\n)CBroadcast_MuteBroadcastChatUser_Response\"N\n%CBroadcast_RemoveUserChatText_Request\x12\x0f\n\x07\x63hat_id\x18\x01 \x01(\x06\x12\x14\n\x0cuser_steamid\x18\x02 \x01(\x06\"(\n&CBroadcast_RemoveUserChatText_Response\"U\n,CBroadcast_GetBroadcastChatUserNames_Request\x12\x0f\n\x07\x63hat_id\x18\x01 \x01(\x06\x12\x14\n\x0cuser_steamid\x18\x02 \x03(\x06\"\xb4\x01\n-CBroadcast_GetBroadcastChatUserNames_Response\x12Q\n\rpersona_names\x18\x01 \x03(\x0b\x32:.CBroadcast_GetBroadcastChatUserNames_Response.PersonaName\x1a\x30\n\x0bPersonaName\x12\x10\n\x08steam_id\x18\x01 \x01(\x06\x12\x0f\n\x07persona\x18\x02 \x01(\t\"\xf8\x01\n,CBroadcast_BroadcastViewerState_Notification\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x61\n\x05state\x18\x02 \x01(\x0e\x32:.CBroadcast_BroadcastViewerState_Notification.EViewerState:\x16k_EViewerNeedsApproval\"T\n\x0c\x45ViewerState\x12\x1a\n\x16k_EViewerNeedsApproval\x10\x01\x12\x15\n\x11k_EViewerWatching\x10\x02\x12\x11\n\rk_EViewerLeft\x10\x03\"F\n.CBroadcast_WaitingBroadcastViewer_Notification\x12\x14\n\x0c\x62roadcast_id\x18\x01 \x01(\x06\"\x95\x01\n+CBroadcast_StopBroadcastUpload_Notification\x12\x14\n\x0c\x62roadcast_id\x18\x01 \x01(\x06\x12\x1a\n\x12\x62roadcast_relay_id\x18\x02 \x01(\x06\x12\x15\n\rupload_result\x18\x03 \x01(\r\x12\x1d\n\x15too_many_poor_uploads\x18\x04 \x01(\x08\"=\n%CBroadcast_SessionClosed_Notification\x12\x14\n\x0c\x62roadcast_id\x18\x01 \x01(\x06\"L\n-CBroadcast_ViewerBroadcastInvite_Notification\x12\x1b\n\x13\x62roadcaster_steamid\x18\x01 \x01(\x06\"T\n\'CBroadcast_BroadcastStatus_Notification\x12\x14\n\x0c\x62roadcast_id\x18\x01 \x01(\x06\x12\x13\n\x0bnum_viewers\x18\x02 \x01(\x05\x32\xe1\x12\n\tBroadcast\x12\xed\x01\n\x15\x42\x65ginBroadcastSession\x12).CBroadcast_BeginBroadcastSession_Request\x1a*.CBroadcast_BeginBroadcastSession_Response\"}\x82\xb5\x18yRequest from client to directory to begin a broadcast session. No data being sent to relay; just available for broadcast.\x12\xba\x01\n\x13\x45ndBroadcastSession\x12\'.CBroadcast_EndBroadcastSession_Request\x1a(.CBroadcast_EndBroadcastSession_Response\"P\x82\xb5\x18LRequest from client to stop a broadcast session. Any uploads will terminate.\x12\xac\x01\n\x14StartBroadcastUpload\x12(.CBroadcast_StartBroadcastUpload_Request\x1a).CBroadcast_StartBroadcastUpload_Response\"?\x82\xb5\x18;Request from client to begin sending video for a broadcast.\x12\x99\x01\n\x19NotifyBroadcastUploadStop\x12\x32.CBroadcast_NotifyBroadcastUploadStop_Notification\x1a\x0b.NoResponse\";\x82\xb5\x18\x37Tells directory that client stopped uploading broadcast\x12\x87\x01\n\x0eWatchBroadcast\x12\".CBroadcast_WatchBroadcast_Request\x1a#.CBroadcast_WatchBroadcast_Response\",\x82\xb5\x18(Request from viewer to watch a broadcast\x12\x96\x01\n\x12GetBroadcastStatus\x12&.CBroadcast_GetBroadcastStatus_Request\x1a\'.CBroadcast_GetBroadcastStatus_Response\"/\x82\xb5\x18+Request from viewer about broadcast details\x12\xa2\x01\n\x11InviteToBroadcast\x12%.CBroadcast_InviteToBroadcast_Request\x1a&.CBroadcast_InviteToBroadcast_Response\">\x82\xb5\x18:Invites another steam user to watch the caller\'s broadcast\x12\xc8\x01\n\x1aSendBroadcastStateToServer\x12..CBroadcast_SendBroadcastStateToServer_Request\x1a/.CBroadcast_SendBroadcastStateToServer_Response\"I\x82\xb5\x18\x45Sends users current broadcast state (permissions, game) to the server\x12\xa2\x01\n\x1fNotifyBroadcastSessionHeartbeat\x12\x38.CBroadcast_NotifyBroadcastSessionHeartbeat_Notification\x1a\x0b.NoResponse\"8\x82\xb5\x18\x34Tells directory broadcast session is still available\x12\x94\x01\n\x14GetBroadcastChatInfo\x12(.CBroadcast_GetBroadcastChatInfo_Request\x1a).CBroadcast_GetBroadcastChatInfo_Response\"\'\x82\xb5\x18#Gets chat room info for a broadcast\x12\x8a\x01\n\x0fPostChatMessage\x12#.CBroadcast_PostChatMessage_Request\x1a$.CBroadcast_PostChatMessage_Response\",\x82\xb5\x18(Post chat message to specified chat room\x12\x96\x01\n\x15MuteBroadcastChatUser\x12).CBroadcast_MuteBroadcastChatUser_Request\x1a*.CBroadcast_MuteBroadcastChatUser_Response\"&\x82\xb5\x18\"Mute a user in your broadcast chat\x12\x94\x01\n\x12RemoveUserChatText\x12&.CBroadcast_RemoveUserChatText_Request\x1a\'.CBroadcast_RemoveUserChatText_Response\"-\x82\xb5\x18)Tell all viewers to remove user chat text\x12\xa3\x01\n\x19GetBroadcastChatUserNames\x12-.CBroadcast_GetBroadcastChatUserNames_Request\x1a..CBroadcast_GetBroadcastChatUserNames_Response\"\'\x82\xb5\x18#Get names for list of users in chat\x1a*\x82\xb5\x18&Methods for Steam broadcast operations2\xea\x08\n\x0f\x42roadcastClient\x12\xa1\x01\n\x1aNotifyBroadcastViewerState\x12-.CBroadcast_BroadcastViewerState_Notification\x1a\x0b.NoResponse\"G\x82\xb5\x18\x43Notification from server to client that a viewers state has changed\x12\xbd\x01\n\x1cNotifyWaitingBroadcastViewer\x12/.CBroadcast_WaitingBroadcastViewer_Notification\x1a\x0b.NoResponse\"_\x82\xb5\x18[Notification from server to client one or more users is waiting for user to start broadcast\x12\xd6\x01\n\x19NotifyStopBroadcastUpload\x12,.CBroadcast_StopBroadcastUpload_Notification\x1a\x0b.NoResponse\"~\x82\xb5\x18zNotification from server to client telling it to stop uploading when the last viewer has disconnected from their broadcast\x12\xb5\x01\n\x13NotifySessionClosed\x12&.CBroadcast_SessionClosed_Notification\x1a\x0b.NoResponse\"i\x82\xb5\x18\x65Notification from server to client telling it a session has been closed unexpectedly by the directory\x12\xc3\x01\n\x1bNotifyViewerBroadcastInvite\x12..CBroadcast_ViewerBroadcastInvite_Notification\x1a\x0b.NoResponse\"g\x82\xb5\x18\x63Notification from server to client that a broadcaster is inviting a viewer to watch their broadcast\x12\x95\x01\n\x15NotifyBroadcastStatus\x12(.CBroadcast_BroadcastStatus_Notification\x1a\x0b.NoResponse\"E\x82\xb5\x18\x41Notification from server to client about current broadcast status\x1a\x04\xc0\xb5\x18\x02\x42\x03\x90\x01\x01'
  ,
  dependencies=[steammessages__unified__base__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)



_CBROADCAST_WATCHBROADCAST_RESPONSE_EWATCHRESPONSE = _descriptor.EnumDescriptor(
  name='EWatchResponse',
  full_name='CBroadcast_WatchBroadcast_Response.EWatchResponse',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EWatchResponseReady', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EWatchResponseNotAvailable', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EWatchResponseWaitingForApproval', index=2, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EWatchResponseWaitingForStart', index=3, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EWatchResponseInvalidSession', index=4, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EWatchResponseTooManyBroadcasts', index=5, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EWatchResponseWaitingForReconnect', index=6, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EWatchResponseSystemNotSupported', index=7, number=8,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EWatchResponseUserRestricted', index=8, number=9,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EWatchResponseClientOutOfDate', index=9, number=10,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EWatchResponsePoorUploadQuality', index=10, number=11,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=1195,
  serialized_end=1617,
)
_sym_db.RegisterEnumDescriptor(_CBROADCAST_WATCHBROADCAST_RESPONSE_EWATCHRESPONSE)

_CBROADCAST_BROADCASTVIEWERSTATE_NOTIFICATION_EVIEWERSTATE = _descriptor.EnumDescriptor(
  name='EViewerState',
  full_name='CBroadcast_BroadcastViewerState_Notification.EViewerState',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EViewerNeedsApproval', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EViewerWatching', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EViewerLeft', index=2, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=3390,
  serialized_end=3474,
)
_sym_db.RegisterEnumDescriptor(_CBROADCAST_BROADCASTVIEWERSTATE_NOTIFICATION_EVIEWERSTATE)


_CBROADCAST_BEGINBROADCASTSESSION_REQUEST = _descriptor.Descriptor(
  name='CBroadcast_BeginBroadcastSession_Request',
  full_name='CBroadcast_BeginBroadcastSession_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='permission', full_name='CBroadcast_BeginBroadcastSession_Request.permission', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='gameid', full_name='CBroadcast_BeginBroadcastSession_Request.gameid', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='client_instance_id', full_name='CBroadcast_BeginBroadcastSession_Request.client_instance_id', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='title', full_name='CBroadcast_BeginBroadcastSession_Request.title', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cellid', full_name='CBroadcast_BeginBroadcastSession_Request.cellid', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rtmp_token', full_name='CBroadcast_BeginBroadcastSession_Request.rtmp_token', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=68,
  serialized_end=225,
)


_CBROADCAST_BEGINBROADCASTSESSION_RESPONSE = _descriptor.Descriptor(
  name='CBroadcast_BeginBroadcastSession_Response',
  full_name='CBroadcast_BeginBroadcastSession_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='broadcast_id', full_name='CBroadcast_BeginBroadcastSession_Response.broadcast_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=227,
  serialized_end=292,
)


_CBROADCAST_ENDBROADCASTSESSION_REQUEST = _descriptor.Descriptor(
  name='CBroadcast_EndBroadcastSession_Request',
  full_name='CBroadcast_EndBroadcastSession_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='broadcast_id', full_name='CBroadcast_EndBroadcastSession_Request.broadcast_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=294,
  serialized_end=356,
)


_CBROADCAST_ENDBROADCASTSESSION_RESPONSE = _descriptor.Descriptor(
  name='CBroadcast_EndBroadcastSession_Response',
  full_name='CBroadcast_EndBroadcastSession_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=358,
  serialized_end=399,
)


_CBROADCAST_STARTBROADCASTUPLOAD_REQUEST = _descriptor.Descriptor(
  name='CBroadcast_StartBroadcastUpload_Request',
  full_name='CBroadcast_StartBroadcastUpload_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='broadcast_id', full_name='CBroadcast_StartBroadcastUpload_Request.broadcast_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cellid', full_name='CBroadcast_StartBroadcastUpload_Request.cellid', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='as_rtmp', full_name='CBroadcast_StartBroadcastUpload_Request.as_rtmp', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='delay_seconds', full_name='CBroadcast_StartBroadcastUpload_Request.delay_seconds', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=401,
  serialized_end=520,
)


_CBROADCAST_STARTBROADCASTUPLOAD_RESPONSE = _descriptor.Descriptor(
  name='CBroadcast_StartBroadcastUpload_Response',
  full_name='CBroadcast_StartBroadcastUpload_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='upload_token', full_name='CBroadcast_StartBroadcastUpload_Response.upload_token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='upload_address', full_name='CBroadcast_StartBroadcastUpload_Response.upload_address', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='upload_relay_id', full_name='CBroadcast_StartBroadcastUpload_Response.upload_relay_id', index=2,
      number=3, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=522,
  serialized_end=635,
)


_CBROADCAST_NOTIFYBROADCASTUPLOADSTOP_NOTIFICATION = _descriptor.Descriptor(
  name='CBroadcast_NotifyBroadcastUploadStop_Notification',
  full_name='CBroadcast_NotifyBroadcastUploadStop_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='broadcast_relay_id', full_name='CBroadcast_NotifyBroadcastUploadStop_Notification.broadcast_relay_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='upload_result', full_name='CBroadcast_NotifyBroadcastUploadStop_Notification.upload_result', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=637,
  serialized_end=739,
)


_CBROADCAST_WATCHBROADCAST_REQUEST = _descriptor.Descriptor(
  name='CBroadcast_WatchBroadcast_Request',
  full_name='CBroadcast_WatchBroadcast_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CBroadcast_WatchBroadcast_Request.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='existing_broadcast_id', full_name='CBroadcast_WatchBroadcast_Request.existing_broadcast_id', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='viewer_token', full_name='CBroadcast_WatchBroadcast_Request.viewer_token', index=2,
      number=3, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='client_ip', full_name='CBroadcast_WatchBroadcast_Request.client_ip', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='client_cell', full_name='CBroadcast_WatchBroadcast_Request.client_cell', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=742,
  serialized_end=887,
)


_CBROADCAST_WATCHBROADCAST_RESPONSE = _descriptor.Descriptor(
  name='CBroadcast_WatchBroadcast_Response',
  full_name='CBroadcast_WatchBroadcast_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='CBroadcast_WatchBroadcast_Response.response', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='mpd_url', full_name='CBroadcast_WatchBroadcast_Response.mpd_url', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='broadcast_id', full_name='CBroadcast_WatchBroadcast_Response.broadcast_id', index=2,
      number=3, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='gameid', full_name='CBroadcast_WatchBroadcast_Response.gameid', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='title', full_name='CBroadcast_WatchBroadcast_Response.title', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='num_viewers', full_name='CBroadcast_WatchBroadcast_Response.num_viewers', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='permission', full_name='CBroadcast_WatchBroadcast_Response.permission', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='is_rtmp', full_name='CBroadcast_WatchBroadcast_Response.is_rtmp', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='seconds_delay', full_name='CBroadcast_WatchBroadcast_Response.seconds_delay', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='viewer_token', full_name='CBroadcast_WatchBroadcast_Response.viewer_token', index=9,
      number=10, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CBROADCAST_WATCHBROADCAST_RESPONSE_EWATCHRESPONSE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=890,
  serialized_end=1617,
)


_CBROADCAST_GETBROADCASTSTATUS_REQUEST = _descriptor.Descriptor(
  name='CBroadcast_GetBroadcastStatus_Request',
  full_name='CBroadcast_GetBroadcastStatus_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CBroadcast_GetBroadcastStatus_Request.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='broadcast_id', full_name='CBroadcast_GetBroadcastStatus_Request.broadcast_id', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1619,
  serialized_end=1697,
)


_CBROADCAST_GETBROADCASTSTATUS_RESPONSE = _descriptor.Descriptor(
  name='CBroadcast_GetBroadcastStatus_Response',
  full_name='CBroadcast_GetBroadcastStatus_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gameid', full_name='CBroadcast_GetBroadcastStatus_Response.gameid', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='title', full_name='CBroadcast_GetBroadcastStatus_Response.title', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='num_viewers', full_name='CBroadcast_GetBroadcastStatus_Response.num_viewers', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='permission', full_name='CBroadcast_GetBroadcastStatus_Response.permission', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='is_rtmp', full_name='CBroadcast_GetBroadcastStatus_Response.is_rtmp', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='seconds_delay', full_name='CBroadcast_GetBroadcastStatus_Response.seconds_delay', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='is_publisher', full_name='CBroadcast_GetBroadcastStatus_Response.is_publisher', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1700,
  serialized_end=1874,
)


_CBROADCAST_INVITETOBROADCAST_REQUEST = _descriptor.Descriptor(
  name='CBroadcast_InviteToBroadcast_Request',
  full_name='CBroadcast_InviteToBroadcast_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CBroadcast_InviteToBroadcast_Request.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='approval_response', full_name='CBroadcast_InviteToBroadcast_Request.approval_response', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1876,
  serialized_end=1958,
)


_CBROADCAST_INVITETOBROADCAST_RESPONSE = _descriptor.Descriptor(
  name='CBroadcast_InviteToBroadcast_Response',
  full_name='CBroadcast_InviteToBroadcast_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='CBroadcast_InviteToBroadcast_Response.success', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1960,
  serialized_end=2016,
)


_CBROADCAST_SENDBROADCASTSTATETOSERVER_REQUEST = _descriptor.Descriptor(
  name='CBroadcast_SendBroadcastStateToServer_Request',
  full_name='CBroadcast_SendBroadcastStateToServer_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='permission', full_name='CBroadcast_SendBroadcastStateToServer_Request.permission', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='gameid', full_name='CBroadcast_SendBroadcastStateToServer_Request.gameid', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='title', full_name='CBroadcast_SendBroadcastStateToServer_Request.title', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='game_data_config', full_name='CBroadcast_SendBroadcastStateToServer_Request.game_data_config', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2018,
  serialized_end=2142,
)


_CBROADCAST_SENDBROADCASTSTATETOSERVER_RESPONSE = _descriptor.Descriptor(
  name='CBroadcast_SendBroadcastStateToServer_Response',
  full_name='CBroadcast_SendBroadcastStateToServer_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2144,
  serialized_end=2192,
)


_CBROADCAST_NOTIFYBROADCASTSESSIONHEARTBEAT_NOTIFICATION = _descriptor.Descriptor(
  name='CBroadcast_NotifyBroadcastSessionHeartbeat_Notification',
  full_name='CBroadcast_NotifyBroadcastSessionHeartbeat_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='broadcast_id', full_name='CBroadcast_NotifyBroadcastSessionHeartbeat_Notification.broadcast_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2194,
  serialized_end=2273,
)


_CBROADCAST_GETBROADCASTCHATINFO_REQUEST = _descriptor.Descriptor(
  name='CBroadcast_GetBroadcastChatInfo_Request',
  full_name='CBroadcast_GetBroadcastChatInfo_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CBroadcast_GetBroadcastChatInfo_Request.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='broadcast_id', full_name='CBroadcast_GetBroadcastChatInfo_Request.broadcast_id', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='client_ip', full_name='CBroadcast_GetBroadcastChatInfo_Request.client_ip', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='client_cell', full_name='CBroadcast_GetBroadcastChatInfo_Request.client_cell', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2275,
  serialized_end=2395,
)


_CBROADCAST_GETBROADCASTCHATINFO_RESPONSE = _descriptor.Descriptor(
  name='CBroadcast_GetBroadcastChatInfo_Response',
  full_name='CBroadcast_GetBroadcastChatInfo_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='chat_id', full_name='CBroadcast_GetBroadcastChatInfo_Response.chat_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='view_url', full_name='CBroadcast_GetBroadcastChatInfo_Response.view_url', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='view_url_template', full_name='CBroadcast_GetBroadcastChatInfo_Response.view_url_template', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2397,
  serialized_end=2501,
)


_CBROADCAST_POSTCHATMESSAGE_REQUEST = _descriptor.Descriptor(
  name='CBroadcast_PostChatMessage_Request',
  full_name='CBroadcast_PostChatMessage_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='chat_id', full_name='CBroadcast_PostChatMessage_Request.chat_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='message', full_name='CBroadcast_PostChatMessage_Request.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='instance_id', full_name='CBroadcast_PostChatMessage_Request.instance_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2503,
  serialized_end=2594,
)


_CBROADCAST_POSTCHATMESSAGE_RESPONSE = _descriptor.Descriptor(
  name='CBroadcast_PostChatMessage_Response',
  full_name='CBroadcast_PostChatMessage_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='persona_name', full_name='CBroadcast_PostChatMessage_Response.persona_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='in_game', full_name='CBroadcast_PostChatMessage_Response.in_game', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='result', full_name='CBroadcast_PostChatMessage_Response.result', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2596,
  serialized_end=2688,
)


_CBROADCAST_MUTEBROADCASTCHATUSER_REQUEST = _descriptor.Descriptor(
  name='CBroadcast_MuteBroadcastChatUser_Request',
  full_name='CBroadcast_MuteBroadcastChatUser_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='chat_id', full_name='CBroadcast_MuteBroadcastChatUser_Request.chat_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='user_steamid', full_name='CBroadcast_MuteBroadcastChatUser_Request.user_steamid', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='muted', full_name='CBroadcast_MuteBroadcastChatUser_Request.muted', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2690,
  serialized_end=2786,
)


_CBROADCAST_MUTEBROADCASTCHATUSER_RESPONSE = _descriptor.Descriptor(
  name='CBroadcast_MuteBroadcastChatUser_Response',
  full_name='CBroadcast_MuteBroadcastChatUser_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2788,
  serialized_end=2831,
)


_CBROADCAST_REMOVEUSERCHATTEXT_REQUEST = _descriptor.Descriptor(
  name='CBroadcast_RemoveUserChatText_Request',
  full_name='CBroadcast_RemoveUserChatText_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='chat_id', full_name='CBroadcast_RemoveUserChatText_Request.chat_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='user_steamid', full_name='CBroadcast_RemoveUserChatText_Request.user_steamid', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2833,
  serialized_end=2911,
)


_CBROADCAST_REMOVEUSERCHATTEXT_RESPONSE = _descriptor.Descriptor(
  name='CBroadcast_RemoveUserChatText_Response',
  full_name='CBroadcast_RemoveUserChatText_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2913,
  serialized_end=2953,
)


_CBROADCAST_GETBROADCASTCHATUSERNAMES_REQUEST = _descriptor.Descriptor(
  name='CBroadcast_GetBroadcastChatUserNames_Request',
  full_name='CBroadcast_GetBroadcastChatUserNames_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='chat_id', full_name='CBroadcast_GetBroadcastChatUserNames_Request.chat_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='user_steamid', full_name='CBroadcast_GetBroadcastChatUserNames_Request.user_steamid', index=1,
      number=2, type=6, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2955,
  serialized_end=3040,
)


_CBROADCAST_GETBROADCASTCHATUSERNAMES_RESPONSE_PERSONANAME = _descriptor.Descriptor(
  name='PersonaName',
  full_name='CBroadcast_GetBroadcastChatUserNames_Response.PersonaName',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='steam_id', full_name='CBroadcast_GetBroadcastChatUserNames_Response.PersonaName.steam_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='persona', full_name='CBroadcast_GetBroadcastChatUserNames_Response.PersonaName.persona', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3175,
  serialized_end=3223,
)

_CBROADCAST_GETBROADCASTCHATUSERNAMES_RESPONSE = _descriptor.Descriptor(
  name='CBroadcast_GetBroadcastChatUserNames_Response',
  full_name='CBroadcast_GetBroadcastChatUserNames_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='persona_names', full_name='CBroadcast_GetBroadcastChatUserNames_Response.persona_names', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CBROADCAST_GETBROADCASTCHATUSERNAMES_RESPONSE_PERSONANAME, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3043,
  serialized_end=3223,
)


_CBROADCAST_BROADCASTVIEWERSTATE_NOTIFICATION = _descriptor.Descriptor(
  name='CBroadcast_BroadcastViewerState_Notification',
  full_name='CBroadcast_BroadcastViewerState_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CBroadcast_BroadcastViewerState_Notification.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='state', full_name='CBroadcast_BroadcastViewerState_Notification.state', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CBROADCAST_BROADCASTVIEWERSTATE_NOTIFICATION_EVIEWERSTATE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3226,
  serialized_end=3474,
)


_CBROADCAST_WAITINGBROADCASTVIEWER_NOTIFICATION = _descriptor.Descriptor(
  name='CBroadcast_WaitingBroadcastViewer_Notification',
  full_name='CBroadcast_WaitingBroadcastViewer_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='broadcast_id', full_name='CBroadcast_WaitingBroadcastViewer_Notification.broadcast_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3476,
  serialized_end=3546,
)


_CBROADCAST_STOPBROADCASTUPLOAD_NOTIFICATION = _descriptor.Descriptor(
  name='CBroadcast_StopBroadcastUpload_Notification',
  full_name='CBroadcast_StopBroadcastUpload_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='broadcast_id', full_name='CBroadcast_StopBroadcastUpload_Notification.broadcast_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='broadcast_relay_id', full_name='CBroadcast_StopBroadcastUpload_Notification.broadcast_relay_id', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='upload_result', full_name='CBroadcast_StopBroadcastUpload_Notification.upload_result', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='too_many_poor_uploads', full_name='CBroadcast_StopBroadcastUpload_Notification.too_many_poor_uploads', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3549,
  serialized_end=3698,
)


_CBROADCAST_SESSIONCLOSED_NOTIFICATION = _descriptor.Descriptor(
  name='CBroadcast_SessionClosed_Notification',
  full_name='CBroadcast_SessionClosed_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='broadcast_id', full_name='CBroadcast_SessionClosed_Notification.broadcast_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3700,
  serialized_end=3761,
)


_CBROADCAST_VIEWERBROADCASTINVITE_NOTIFICATION = _descriptor.Descriptor(
  name='CBroadcast_ViewerBroadcastInvite_Notification',
  full_name='CBroadcast_ViewerBroadcastInvite_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='broadcaster_steamid', full_name='CBroadcast_ViewerBroadcastInvite_Notification.broadcaster_steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3763,
  serialized_end=3839,
)


_CBROADCAST_BROADCASTSTATUS_NOTIFICATION = _descriptor.Descriptor(
  name='CBroadcast_BroadcastStatus_Notification',
  full_name='CBroadcast_BroadcastStatus_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='broadcast_id', full_name='CBroadcast_BroadcastStatus_Notification.broadcast_id', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='num_viewers', full_name='CBroadcast_BroadcastStatus_Notification.num_viewers', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3841,
  serialized_end=3925,
)

_CBROADCAST_WATCHBROADCAST_RESPONSE.fields_by_name['response'].enum_type = _CBROADCAST_WATCHBROADCAST_RESPONSE_EWATCHRESPONSE
_CBROADCAST_WATCHBROADCAST_RESPONSE_EWATCHRESPONSE.containing_type = _CBROADCAST_WATCHBROADCAST_RESPONSE
_CBROADCAST_GETBROADCASTCHATUSERNAMES_RESPONSE_PERSONANAME.containing_type = _CBROADCAST_GETBROADCASTCHATUSERNAMES_RESPONSE
_CBROADCAST_GETBROADCASTCHATUSERNAMES_RESPONSE.fields_by_name['persona_names'].message_type = _CBROADCAST_GETBROADCASTCHATUSERNAMES_RESPONSE_PERSONANAME
_CBROADCAST_BROADCASTVIEWERSTATE_NOTIFICATION.fields_by_name['state'].enum_type = _CBROADCAST_BROADCASTVIEWERSTATE_NOTIFICATION_EVIEWERSTATE
_CBROADCAST_BROADCASTVIEWERSTATE_NOTIFICATION_EVIEWERSTATE.containing_type = _CBROADCAST_BROADCASTVIEWERSTATE_NOTIFICATION
DESCRIPTOR.message_types_by_name['CBroadcast_BeginBroadcastSession_Request'] = _CBROADCAST_BEGINBROADCASTSESSION_REQUEST
DESCRIPTOR.message_types_by_name['CBroadcast_BeginBroadcastSession_Response'] = _CBROADCAST_BEGINBROADCASTSESSION_RESPONSE
DESCRIPTOR.message_types_by_name['CBroadcast_EndBroadcastSession_Request'] = _CBROADCAST_ENDBROADCASTSESSION_REQUEST
DESCRIPTOR.message_types_by_name['CBroadcast_EndBroadcastSession_Response'] = _CBROADCAST_ENDBROADCASTSESSION_RESPONSE
DESCRIPTOR.message_types_by_name['CBroadcast_StartBroadcastUpload_Request'] = _CBROADCAST_STARTBROADCASTUPLOAD_REQUEST
DESCRIPTOR.message_types_by_name['CBroadcast_StartBroadcastUpload_Response'] = _CBROADCAST_STARTBROADCASTUPLOAD_RESPONSE
DESCRIPTOR.message_types_by_name['CBroadcast_NotifyBroadcastUploadStop_Notification'] = _CBROADCAST_NOTIFYBROADCASTUPLOADSTOP_NOTIFICATION
DESCRIPTOR.message_types_by_name['CBroadcast_WatchBroadcast_Request'] = _CBROADCAST_WATCHBROADCAST_REQUEST
DESCRIPTOR.message_types_by_name['CBroadcast_WatchBroadcast_Response'] = _CBROADCAST_WATCHBROADCAST_RESPONSE
DESCRIPTOR.message_types_by_name['CBroadcast_GetBroadcastStatus_Request'] = _CBROADCAST_GETBROADCASTSTATUS_REQUEST
DESCRIPTOR.message_types_by_name['CBroadcast_GetBroadcastStatus_Response'] = _CBROADCAST_GETBROADCASTSTATUS_RESPONSE
DESCRIPTOR.message_types_by_name['CBroadcast_InviteToBroadcast_Request'] = _CBROADCAST_INVITETOBROADCAST_REQUEST
DESCRIPTOR.message_types_by_name['CBroadcast_InviteToBroadcast_Response'] = _CBROADCAST_INVITETOBROADCAST_RESPONSE
DESCRIPTOR.message_types_by_name['CBroadcast_SendBroadcastStateToServer_Request'] = _CBROADCAST_SENDBROADCASTSTATETOSERVER_REQUEST
DESCRIPTOR.message_types_by_name['CBroadcast_SendBroadcastStateToServer_Response'] = _CBROADCAST_SENDBROADCASTSTATETOSERVER_RESPONSE
DESCRIPTOR.message_types_by_name['CBroadcast_NotifyBroadcastSessionHeartbeat_Notification'] = _CBROADCAST_NOTIFYBROADCASTSESSIONHEARTBEAT_NOTIFICATION
DESCRIPTOR.message_types_by_name['CBroadcast_GetBroadcastChatInfo_Request'] = _CBROADCAST_GETBROADCASTCHATINFO_REQUEST
DESCRIPTOR.message_types_by_name['CBroadcast_GetBroadcastChatInfo_Response'] = _CBROADCAST_GETBROADCASTCHATINFO_RESPONSE
DESCRIPTOR.message_types_by_name['CBroadcast_PostChatMessage_Request'] = _CBROADCAST_POSTCHATMESSAGE_REQUEST
DESCRIPTOR.message_types_by_name['CBroadcast_PostChatMessage_Response'] = _CBROADCAST_POSTCHATMESSAGE_RESPONSE
DESCRIPTOR.message_types_by_name['CBroadcast_MuteBroadcastChatUser_Request'] = _CBROADCAST_MUTEBROADCASTCHATUSER_REQUEST
DESCRIPTOR.message_types_by_name['CBroadcast_MuteBroadcastChatUser_Response'] = _CBROADCAST_MUTEBROADCASTCHATUSER_RESPONSE
DESCRIPTOR.message_types_by_name['CBroadcast_RemoveUserChatText_Request'] = _CBROADCAST_REMOVEUSERCHATTEXT_REQUEST
DESCRIPTOR.message_types_by_name['CBroadcast_RemoveUserChatText_Response'] = _CBROADCAST_REMOVEUSERCHATTEXT_RESPONSE
DESCRIPTOR.message_types_by_name['CBroadcast_GetBroadcastChatUserNames_Request'] = _CBROADCAST_GETBROADCASTCHATUSERNAMES_REQUEST
DESCRIPTOR.message_types_by_name['CBroadcast_GetBroadcastChatUserNames_Response'] = _CBROADCAST_GETBROADCASTCHATUSERNAMES_RESPONSE
DESCRIPTOR.message_types_by_name['CBroadcast_BroadcastViewerState_Notification'] = _CBROADCAST_BROADCASTVIEWERSTATE_NOTIFICATION
DESCRIPTOR.message_types_by_name['CBroadcast_WaitingBroadcastViewer_Notification'] = _CBROADCAST_WAITINGBROADCASTVIEWER_NOTIFICATION
DESCRIPTOR.message_types_by_name['CBroadcast_StopBroadcastUpload_Notification'] = _CBROADCAST_STOPBROADCASTUPLOAD_NOTIFICATION
DESCRIPTOR.message_types_by_name['CBroadcast_SessionClosed_Notification'] = _CBROADCAST_SESSIONCLOSED_NOTIFICATION
DESCRIPTOR.message_types_by_name['CBroadcast_ViewerBroadcastInvite_Notification'] = _CBROADCAST_VIEWERBROADCASTINVITE_NOTIFICATION
DESCRIPTOR.message_types_by_name['CBroadcast_BroadcastStatus_Notification'] = _CBROADCAST_BROADCASTSTATUS_NOTIFICATION

CBroadcast_BeginBroadcastSession_Request = _reflection.GeneratedProtocolMessageType('CBroadcast_BeginBroadcastSession_Request', (_message.Message,), dict(
  DESCRIPTOR = _CBROADCAST_BEGINBROADCASTSESSION_REQUEST,
  __module__ = 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_BeginBroadcastSession_Request)
  ))
_sym_db.RegisterMessage(CBroadcast_BeginBroadcastSession_Request)

CBroadcast_BeginBroadcastSession_Response = _reflection.GeneratedProtocolMessageType('CBroadcast_BeginBroadcastSession_Response', (_message.Message,), dict(
  DESCRIPTOR = _CBROADCAST_BEGINBROADCASTSESSION_RESPONSE,
  __module__ = 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_BeginBroadcastSession_Response)
  ))
_sym_db.RegisterMessage(CBroadcast_BeginBroadcastSession_Response)

CBroadcast_EndBroadcastSession_Request = _reflection.GeneratedProtocolMessageType('CBroadcast_EndBroadcastSession_Request', (_message.Message,), dict(
  DESCRIPTOR = _CBROADCAST_ENDBROADCASTSESSION_REQUEST,
  __module__ = 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_EndBroadcastSession_Request)
  ))
_sym_db.RegisterMessage(CBroadcast_EndBroadcastSession_Request)

CBroadcast_EndBroadcastSession_Response = _reflection.GeneratedProtocolMessageType('CBroadcast_EndBroadcastSession_Response', (_message.Message,), dict(
  DESCRIPTOR = _CBROADCAST_ENDBROADCASTSESSION_RESPONSE,
  __module__ = 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_EndBroadcastSession_Response)
  ))
_sym_db.RegisterMessage(CBroadcast_EndBroadcastSession_Response)

CBroadcast_StartBroadcastUpload_Request = _reflection.GeneratedProtocolMessageType('CBroadcast_StartBroadcastUpload_Request', (_message.Message,), dict(
  DESCRIPTOR = _CBROADCAST_STARTBROADCASTUPLOAD_REQUEST,
  __module__ = 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_StartBroadcastUpload_Request)
  ))
_sym_db.RegisterMessage(CBroadcast_StartBroadcastUpload_Request)

CBroadcast_StartBroadcastUpload_Response = _reflection.GeneratedProtocolMessageType('CBroadcast_StartBroadcastUpload_Response', (_message.Message,), dict(
  DESCRIPTOR = _CBROADCAST_STARTBROADCASTUPLOAD_RESPONSE,
  __module__ = 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_StartBroadcastUpload_Response)
  ))
_sym_db.RegisterMessage(CBroadcast_StartBroadcastUpload_Response)

CBroadcast_NotifyBroadcastUploadStop_Notification = _reflection.GeneratedProtocolMessageType('CBroadcast_NotifyBroadcastUploadStop_Notification', (_message.Message,), dict(
  DESCRIPTOR = _CBROADCAST_NOTIFYBROADCASTUPLOADSTOP_NOTIFICATION,
  __module__ = 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_NotifyBroadcastUploadStop_Notification)
  ))
_sym_db.RegisterMessage(CBroadcast_NotifyBroadcastUploadStop_Notification)

CBroadcast_WatchBroadcast_Request = _reflection.GeneratedProtocolMessageType('CBroadcast_WatchBroadcast_Request', (_message.Message,), dict(
  DESCRIPTOR = _CBROADCAST_WATCHBROADCAST_REQUEST,
  __module__ = 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_WatchBroadcast_Request)
  ))
_sym_db.RegisterMessage(CBroadcast_WatchBroadcast_Request)

CBroadcast_WatchBroadcast_Response = _reflection.GeneratedProtocolMessageType('CBroadcast_WatchBroadcast_Response', (_message.Message,), dict(
  DESCRIPTOR = _CBROADCAST_WATCHBROADCAST_RESPONSE,
  __module__ = 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_WatchBroadcast_Response)
  ))
_sym_db.RegisterMessage(CBroadcast_WatchBroadcast_Response)

CBroadcast_GetBroadcastStatus_Request = _reflection.GeneratedProtocolMessageType('CBroadcast_GetBroadcastStatus_Request', (_message.Message,), dict(
  DESCRIPTOR = _CBROADCAST_GETBROADCASTSTATUS_REQUEST,
  __module__ = 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_GetBroadcastStatus_Request)
  ))
_sym_db.RegisterMessage(CBroadcast_GetBroadcastStatus_Request)

CBroadcast_GetBroadcastStatus_Response = _reflection.GeneratedProtocolMessageType('CBroadcast_GetBroadcastStatus_Response', (_message.Message,), dict(
  DESCRIPTOR = _CBROADCAST_GETBROADCASTSTATUS_RESPONSE,
  __module__ = 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_GetBroadcastStatus_Response)
  ))
_sym_db.RegisterMessage(CBroadcast_GetBroadcastStatus_Response)

CBroadcast_InviteToBroadcast_Request = _reflection.GeneratedProtocolMessageType('CBroadcast_InviteToBroadcast_Request', (_message.Message,), dict(
  DESCRIPTOR = _CBROADCAST_INVITETOBROADCAST_REQUEST,
  __module__ = 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_InviteToBroadcast_Request)
  ))
_sym_db.RegisterMessage(CBroadcast_InviteToBroadcast_Request)

CBroadcast_InviteToBroadcast_Response = _reflection.GeneratedProtocolMessageType('CBroadcast_InviteToBroadcast_Response', (_message.Message,), dict(
  DESCRIPTOR = _CBROADCAST_INVITETOBROADCAST_RESPONSE,
  __module__ = 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_InviteToBroadcast_Response)
  ))
_sym_db.RegisterMessage(CBroadcast_InviteToBroadcast_Response)

CBroadcast_SendBroadcastStateToServer_Request = _reflection.GeneratedProtocolMessageType('CBroadcast_SendBroadcastStateToServer_Request', (_message.Message,), dict(
  DESCRIPTOR = _CBROADCAST_SENDBROADCASTSTATETOSERVER_REQUEST,
  __module__ = 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_SendBroadcastStateToServer_Request)
  ))
_sym_db.RegisterMessage(CBroadcast_SendBroadcastStateToServer_Request)

CBroadcast_SendBroadcastStateToServer_Response = _reflection.GeneratedProtocolMessageType('CBroadcast_SendBroadcastStateToServer_Response', (_message.Message,), dict(
  DESCRIPTOR = _CBROADCAST_SENDBROADCASTSTATETOSERVER_RESPONSE,
  __module__ = 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_SendBroadcastStateToServer_Response)
  ))
_sym_db.RegisterMessage(CBroadcast_SendBroadcastStateToServer_Response)

CBroadcast_NotifyBroadcastSessionHeartbeat_Notification = _reflection.GeneratedProtocolMessageType('CBroadcast_NotifyBroadcastSessionHeartbeat_Notification', (_message.Message,), dict(
  DESCRIPTOR = _CBROADCAST_NOTIFYBROADCASTSESSIONHEARTBEAT_NOTIFICATION,
  __module__ = 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_NotifyBroadcastSessionHeartbeat_Notification)
  ))
_sym_db.RegisterMessage(CBroadcast_NotifyBroadcastSessionHeartbeat_Notification)

CBroadcast_GetBroadcastChatInfo_Request = _reflection.GeneratedProtocolMessageType('CBroadcast_GetBroadcastChatInfo_Request', (_message.Message,), dict(
  DESCRIPTOR = _CBROADCAST_GETBROADCASTCHATINFO_REQUEST,
  __module__ = 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_GetBroadcastChatInfo_Request)
  ))
_sym_db.RegisterMessage(CBroadcast_GetBroadcastChatInfo_Request)

CBroadcast_GetBroadcastChatInfo_Response = _reflection.GeneratedProtocolMessageType('CBroadcast_GetBroadcastChatInfo_Response', (_message.Message,), dict(
  DESCRIPTOR = _CBROADCAST_GETBROADCASTCHATINFO_RESPONSE,
  __module__ = 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_GetBroadcastChatInfo_Response)
  ))
_sym_db.RegisterMessage(CBroadcast_GetBroadcastChatInfo_Response)

CBroadcast_PostChatMessage_Request = _reflection.GeneratedProtocolMessageType('CBroadcast_PostChatMessage_Request', (_message.Message,), dict(
  DESCRIPTOR = _CBROADCAST_POSTCHATMESSAGE_REQUEST,
  __module__ = 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_PostChatMessage_Request)
  ))
_sym_db.RegisterMessage(CBroadcast_PostChatMessage_Request)

CBroadcast_PostChatMessage_Response = _reflection.GeneratedProtocolMessageType('CBroadcast_PostChatMessage_Response', (_message.Message,), dict(
  DESCRIPTOR = _CBROADCAST_POSTCHATMESSAGE_RESPONSE,
  __module__ = 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_PostChatMessage_Response)
  ))
_sym_db.RegisterMessage(CBroadcast_PostChatMessage_Response)

CBroadcast_MuteBroadcastChatUser_Request = _reflection.GeneratedProtocolMessageType('CBroadcast_MuteBroadcastChatUser_Request', (_message.Message,), dict(
  DESCRIPTOR = _CBROADCAST_MUTEBROADCASTCHATUSER_REQUEST,
  __module__ = 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_MuteBroadcastChatUser_Request)
  ))
_sym_db.RegisterMessage(CBroadcast_MuteBroadcastChatUser_Request)

CBroadcast_MuteBroadcastChatUser_Response = _reflection.GeneratedProtocolMessageType('CBroadcast_MuteBroadcastChatUser_Response', (_message.Message,), dict(
  DESCRIPTOR = _CBROADCAST_MUTEBROADCASTCHATUSER_RESPONSE,
  __module__ = 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_MuteBroadcastChatUser_Response)
  ))
_sym_db.RegisterMessage(CBroadcast_MuteBroadcastChatUser_Response)

CBroadcast_RemoveUserChatText_Request = _reflection.GeneratedProtocolMessageType('CBroadcast_RemoveUserChatText_Request', (_message.Message,), dict(
  DESCRIPTOR = _CBROADCAST_REMOVEUSERCHATTEXT_REQUEST,
  __module__ = 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_RemoveUserChatText_Request)
  ))
_sym_db.RegisterMessage(CBroadcast_RemoveUserChatText_Request)

CBroadcast_RemoveUserChatText_Response = _reflection.GeneratedProtocolMessageType('CBroadcast_RemoveUserChatText_Response', (_message.Message,), dict(
  DESCRIPTOR = _CBROADCAST_REMOVEUSERCHATTEXT_RESPONSE,
  __module__ = 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_RemoveUserChatText_Response)
  ))
_sym_db.RegisterMessage(CBroadcast_RemoveUserChatText_Response)

CBroadcast_GetBroadcastChatUserNames_Request = _reflection.GeneratedProtocolMessageType('CBroadcast_GetBroadcastChatUserNames_Request', (_message.Message,), dict(
  DESCRIPTOR = _CBROADCAST_GETBROADCASTCHATUSERNAMES_REQUEST,
  __module__ = 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_GetBroadcastChatUserNames_Request)
  ))
_sym_db.RegisterMessage(CBroadcast_GetBroadcastChatUserNames_Request)

CBroadcast_GetBroadcastChatUserNames_Response = _reflection.GeneratedProtocolMessageType('CBroadcast_GetBroadcastChatUserNames_Response', (_message.Message,), dict(

  PersonaName = _reflection.GeneratedProtocolMessageType('PersonaName', (_message.Message,), dict(
    DESCRIPTOR = _CBROADCAST_GETBROADCASTCHATUSERNAMES_RESPONSE_PERSONANAME,
    __module__ = 'steammessages_broadcast_pb2'
    # @@protoc_insertion_point(class_scope:CBroadcast_GetBroadcastChatUserNames_Response.PersonaName)
    ))
  ,
  DESCRIPTOR = _CBROADCAST_GETBROADCASTCHATUSERNAMES_RESPONSE,
  __module__ = 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_GetBroadcastChatUserNames_Response)
  ))
_sym_db.RegisterMessage(CBroadcast_GetBroadcastChatUserNames_Response)
_sym_db.RegisterMessage(CBroadcast_GetBroadcastChatUserNames_Response.PersonaName)

CBroadcast_BroadcastViewerState_Notification = _reflection.GeneratedProtocolMessageType('CBroadcast_BroadcastViewerState_Notification', (_message.Message,), dict(
  DESCRIPTOR = _CBROADCAST_BROADCASTVIEWERSTATE_NOTIFICATION,
  __module__ = 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_BroadcastViewerState_Notification)
  ))
_sym_db.RegisterMessage(CBroadcast_BroadcastViewerState_Notification)

CBroadcast_WaitingBroadcastViewer_Notification = _reflection.GeneratedProtocolMessageType('CBroadcast_WaitingBroadcastViewer_Notification', (_message.Message,), dict(
  DESCRIPTOR = _CBROADCAST_WAITINGBROADCASTVIEWER_NOTIFICATION,
  __module__ = 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_WaitingBroadcastViewer_Notification)
  ))
_sym_db.RegisterMessage(CBroadcast_WaitingBroadcastViewer_Notification)

CBroadcast_StopBroadcastUpload_Notification = _reflection.GeneratedProtocolMessageType('CBroadcast_StopBroadcastUpload_Notification', (_message.Message,), dict(
  DESCRIPTOR = _CBROADCAST_STOPBROADCASTUPLOAD_NOTIFICATION,
  __module__ = 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_StopBroadcastUpload_Notification)
  ))
_sym_db.RegisterMessage(CBroadcast_StopBroadcastUpload_Notification)

CBroadcast_SessionClosed_Notification = _reflection.GeneratedProtocolMessageType('CBroadcast_SessionClosed_Notification', (_message.Message,), dict(
  DESCRIPTOR = _CBROADCAST_SESSIONCLOSED_NOTIFICATION,
  __module__ = 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_SessionClosed_Notification)
  ))
_sym_db.RegisterMessage(CBroadcast_SessionClosed_Notification)

CBroadcast_ViewerBroadcastInvite_Notification = _reflection.GeneratedProtocolMessageType('CBroadcast_ViewerBroadcastInvite_Notification', (_message.Message,), dict(
  DESCRIPTOR = _CBROADCAST_VIEWERBROADCASTINVITE_NOTIFICATION,
  __module__ = 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_ViewerBroadcastInvite_Notification)
  ))
_sym_db.RegisterMessage(CBroadcast_ViewerBroadcastInvite_Notification)

CBroadcast_BroadcastStatus_Notification = _reflection.GeneratedProtocolMessageType('CBroadcast_BroadcastStatus_Notification', (_message.Message,), dict(
  DESCRIPTOR = _CBROADCAST_BROADCASTSTATUS_NOTIFICATION,
  __module__ = 'steammessages_broadcast_pb2'
  # @@protoc_insertion_point(class_scope:CBroadcast_BroadcastStatus_Notification)
  ))
_sym_db.RegisterMessage(CBroadcast_BroadcastStatus_Notification)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), b'\220\001\001')

_BROADCAST = _descriptor.ServiceDescriptor(
  name='Broadcast',
  full_name='Broadcast',
  file=DESCRIPTOR,
  index=0,
  options=_descriptor._ParseOptions(descriptor_pb2.ServiceOptions(), b'\202\265\030&Methods for Steam broadcast operations'),
  serialized_start=3928,
  serialized_end=6329,
  methods=[
  _descriptor.MethodDescriptor(
    name='BeginBroadcastSession',
    full_name='Broadcast.BeginBroadcastSession',
    index=0,
    containing_service=None,
    input_type=_CBROADCAST_BEGINBROADCASTSESSION_REQUEST,
    output_type=_CBROADCAST_BEGINBROADCASTSESSION_RESPONSE,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), b'\202\265\030yRequest from client to directory to begin a broadcast session. No data being sent to relay; just available for broadcast.'),
  ),
  _descriptor.MethodDescriptor(
    name='EndBroadcastSession',
    full_name='Broadcast.EndBroadcastSession',
    index=1,
    containing_service=None,
    input_type=_CBROADCAST_ENDBROADCASTSESSION_REQUEST,
    output_type=_CBROADCAST_ENDBROADCASTSESSION_RESPONSE,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), b'\202\265\030LRequest from client to stop a broadcast session. Any uploads will terminate.'),
  ),
  _descriptor.MethodDescriptor(
    name='StartBroadcastUpload',
    full_name='Broadcast.StartBroadcastUpload',
    index=2,
    containing_service=None,
    input_type=_CBROADCAST_STARTBROADCASTUPLOAD_REQUEST,
    output_type=_CBROADCAST_STARTBROADCASTUPLOAD_RESPONSE,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), b'\202\265\030;Request from client to begin sending video for a broadcast.'),
  ),
  _descriptor.MethodDescriptor(
    name='NotifyBroadcastUploadStop',
    full_name='Broadcast.NotifyBroadcastUploadStop',
    index=3,
    containing_service=None,
    input_type=_CBROADCAST_NOTIFYBROADCASTUPLOADSTOP_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), b'\202\265\0307Tells directory that client stopped uploading broadcast'),
  ),
  _descriptor.MethodDescriptor(
    name='WatchBroadcast',
    full_name='Broadcast.WatchBroadcast',
    index=4,
    containing_service=None,
    input_type=_CBROADCAST_WATCHBROADCAST_REQUEST,
    output_type=_CBROADCAST_WATCHBROADCAST_RESPONSE,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), b'\202\265\030(Request from viewer to watch a broadcast'),
  ),
  _descriptor.MethodDescriptor(
    name='GetBroadcastStatus',
    full_name='Broadcast.GetBroadcastStatus',
    index=5,
    containing_service=None,
    input_type=_CBROADCAST_GETBROADCASTSTATUS_REQUEST,
    output_type=_CBROADCAST_GETBROADCASTSTATUS_RESPONSE,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), b'\202\265\030+Request from viewer about broadcast details'),
  ),
  _descriptor.MethodDescriptor(
    name='InviteToBroadcast',
    full_name='Broadcast.InviteToBroadcast',
    index=6,
    containing_service=None,
    input_type=_CBROADCAST_INVITETOBROADCAST_REQUEST,
    output_type=_CBROADCAST_INVITETOBROADCAST_RESPONSE,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), b'\202\265\030:Invites another steam user to watch the caller\'s broadcast'),
  ),
  _descriptor.MethodDescriptor(
    name='SendBroadcastStateToServer',
    full_name='Broadcast.SendBroadcastStateToServer',
    index=7,
    containing_service=None,
    input_type=_CBROADCAST_SENDBROADCASTSTATETOSERVER_REQUEST,
    output_type=_CBROADCAST_SENDBROADCASTSTATETOSERVER_RESPONSE,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), b'\202\265\030ESends users current broadcast state (permissions, game) to the server'),
  ),
  _descriptor.MethodDescriptor(
    name='NotifyBroadcastSessionHeartbeat',
    full_name='Broadcast.NotifyBroadcastSessionHeartbeat',
    index=8,
    containing_service=None,
    input_type=_CBROADCAST_NOTIFYBROADCASTSESSIONHEARTBEAT_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), b'\202\265\0304Tells directory broadcast session is still available'),
  ),
  _descriptor.MethodDescriptor(
    name='GetBroadcastChatInfo',
    full_name='Broadcast.GetBroadcastChatInfo',
    index=9,
    containing_service=None,
    input_type=_CBROADCAST_GETBROADCASTCHATINFO_REQUEST,
    output_type=_CBROADCAST_GETBROADCASTCHATINFO_RESPONSE,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), b'\202\265\030#Gets chat room info for a broadcast'),
  ),
  _descriptor.MethodDescriptor(
    name='PostChatMessage',
    full_name='Broadcast.PostChatMessage',
    index=10,
    containing_service=None,
    input_type=_CBROADCAST_POSTCHATMESSAGE_REQUEST,
    output_type=_CBROADCAST_POSTCHATMESSAGE_RESPONSE,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), b'\202\265\030(Post chat message to specified chat room'),
  ),
  _descriptor.MethodDescriptor(
    name='MuteBroadcastChatUser',
    full_name='Broadcast.MuteBroadcastChatUser',
    index=11,
    containing_service=None,
    input_type=_CBROADCAST_MUTEBROADCASTCHATUSER_REQUEST,
    output_type=_CBROADCAST_MUTEBROADCASTCHATUSER_RESPONSE,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), b'\202\265\030\"Mute a user in your broadcast chat'),
  ),
  _descriptor.MethodDescriptor(
    name='RemoveUserChatText',
    full_name='Broadcast.RemoveUserChatText',
    index=12,
    containing_service=None,
    input_type=_CBROADCAST_REMOVEUSERCHATTEXT_REQUEST,
    output_type=_CBROADCAST_REMOVEUSERCHATTEXT_RESPONSE,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), b'\202\265\030)Tell all viewers to remove user chat text'),
  ),
  _descriptor.MethodDescriptor(
    name='GetBroadcastChatUserNames',
    full_name='Broadcast.GetBroadcastChatUserNames',
    index=13,
    containing_service=None,
    input_type=_CBROADCAST_GETBROADCASTCHATUSERNAMES_REQUEST,
    output_type=_CBROADCAST_GETBROADCASTCHATUSERNAMES_RESPONSE,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), b'\202\265\030#Get names for list of users in chat'),
  ),
])

Broadcast = service_reflection.GeneratedServiceType('Broadcast', (_service.Service,), dict(
  DESCRIPTOR = _BROADCAST,
  __module__ = 'steammessages_broadcast_pb2'
  ))

Broadcast_Stub = service_reflection.GeneratedServiceStubType('Broadcast_Stub', (Broadcast,), dict(
  DESCRIPTOR = _BROADCAST,
  __module__ = 'steammessages_broadcast_pb2'
  ))



_BROADCASTCLIENT = _descriptor.ServiceDescriptor(
  name='BroadcastClient',
  full_name='BroadcastClient',
  file=DESCRIPTOR,
  index=1,
  options=_descriptor._ParseOptions(descriptor_pb2.ServiceOptions(), b'\300\265\030\002'),
  serialized_start=6332,
  serialized_end=7462,
  methods=[
  _descriptor.MethodDescriptor(
    name='NotifyBroadcastViewerState',
    full_name='BroadcastClient.NotifyBroadcastViewerState',
    index=0,
    containing_service=None,
    input_type=_CBROADCAST_BROADCASTVIEWERSTATE_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), b'\202\265\030CNotification from server to client that a viewers state has changed'),
  ),
  _descriptor.MethodDescriptor(
    name='NotifyWaitingBroadcastViewer',
    full_name='BroadcastClient.NotifyWaitingBroadcastViewer',
    index=1,
    containing_service=None,
    input_type=_CBROADCAST_WAITINGBROADCASTVIEWER_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), b'\202\265\030[Notification from server to client one or more users is waiting for user to start broadcast'),
  ),
  _descriptor.MethodDescriptor(
    name='NotifyStopBroadcastUpload',
    full_name='BroadcastClient.NotifyStopBroadcastUpload',
    index=2,
    containing_service=None,
    input_type=_CBROADCAST_STOPBROADCASTUPLOAD_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), b'\202\265\030zNotification from server to client telling it to stop uploading when the last viewer has disconnected from their broadcast'),
  ),
  _descriptor.MethodDescriptor(
    name='NotifySessionClosed',
    full_name='BroadcastClient.NotifySessionClosed',
    index=3,
    containing_service=None,
    input_type=_CBROADCAST_SESSIONCLOSED_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), b'\202\265\030eNotification from server to client telling it a session has been closed unexpectedly by the directory'),
  ),
  _descriptor.MethodDescriptor(
    name='NotifyViewerBroadcastInvite',
    full_name='BroadcastClient.NotifyViewerBroadcastInvite',
    index=4,
    containing_service=None,
    input_type=_CBROADCAST_VIEWERBROADCASTINVITE_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), b'\202\265\030cNotification from server to client that a broadcaster is inviting a viewer to watch their broadcast'),
  ),
  _descriptor.MethodDescriptor(
    name='NotifyBroadcastStatus',
    full_name='BroadcastClient.NotifyBroadcastStatus',
    index=5,
    containing_service=None,
    input_type=_CBROADCAST_BROADCASTSTATUS_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), b'\202\265\030ANotification from server to client about current broadcast status'),
  ),
])

BroadcastClient = service_reflection.GeneratedServiceType('BroadcastClient', (_service.Service,), dict(
  DESCRIPTOR = _BROADCASTCLIENT,
  __module__ = 'steammessages_broadcast_pb2'
  ))

BroadcastClient_Stub = service_reflection.GeneratedServiceStubType('BroadcastClient_Stub', (BroadcastClient,), dict(
  DESCRIPTOR = _BROADCASTCLIENT,
  __module__ = 'steammessages_broadcast_pb2'
  ))


# @@protoc_insertion_point(module_scope)
